==> zio-aws-securityhub_2.13-5.17.124.2-sources.jar: zio/aws/securityhub/model/AwsElasticsearchDomainServiceSoftwareOptions.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.NonEmptyString
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AwsElasticsearchDomainServiceSoftwareOptions(
    automatedUpdateDate: Option[NonEmptyString] = None,
    cancellable: Option[Boolean] = None,
    currentVersion: Option[NonEmptyString] = None,
    description: Option[NonEmptyString] = None,
    newVersion: Option[NonEmptyString] = None,
    updateAvailable: Option[Boolean] = None,
    updateStatus: Option[NonEmptyString] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions = {
    import AwsElasticsearchDomainServiceSoftwareOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions
      .builder()
      .optionallyWith(
        automatedUpdateDate.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.automatedUpdateDate)
      .optionallyWith(cancellable.map(value => value: java.lang.Boolean))(
        _.cancellable
      )
      .optionallyWith(
        currentVersion.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.currentVersion)
      .optionallyWith(
        description.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(
        newVersion.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.newVersion)
      .optionallyWith(updateAvailable.map(value => value: java.lang.Boolean))(
        _.updateAvailable
      )
      .optionallyWith(
        updateStatus.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.updateStatus)
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions.ReadOnly =
    zio.aws.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions
      .wrap(buildAwsValue())
}
object AwsElasticsearchDomainServiceSoftwareOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions =
      zio.aws.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions(
        automatedUpdateDate.map(value => value),
        cancellable.map(value => value),
        currentVersion.map(value => value),
        description.map(value => value),
        newVersion.map(value => value),
        updateAvailable.map(value => value),
        updateStatus.map(value => value)
      )
    def automatedUpdateDate: Option[NonEmptyString]
    def cancellable: Option[Boolean]
    def currentVersion: Option[NonEmptyString]
    def description: Option[NonEmptyString]
    def newVersion: Option[NonEmptyString]
    def updateAvailable: Option[Boolean]
    def updateStatus: Option[NonEmptyString]
    def getAutomatedUpdateDate: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("automatedUpdateDate", automatedUpdateDate)
    def getCancellable: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("cancellable", cancellable)
    def getCurrentVersion: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("currentVersion", currentVersion)
    def getDescription: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("description", description)
    def getNewVersion: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("newVersion", newVersion)
    def getUpdateAvailable: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("updateAvailable", updateAvailable)
    def getUpdateStatus: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("updateStatus", updateStatus)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions
  ) extends zio.aws.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions.ReadOnly {
    override val automatedUpdateDate: Option[NonEmptyString] = scala
      .Option(impl.automatedUpdateDate())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val cancellable: Option[Boolean] =
      scala.Option(impl.cancellable()).map(value => value: Boolean)
    override val currentVersion: Option[NonEmptyString] = scala
      .Option(impl.currentVersion())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val description: Option[NonEmptyString] = scala
      .Option(impl.description())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val newVersion: Option[NonEmptyString] = scala
      .Option(impl.newVersion())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val updateAvailable: Option[Boolean] =
      scala.Option(impl.updateAvailable()).map(value => value: Boolean)
    override val updateStatus: Option[NonEmptyString] = scala
      .Option(impl.updateStatus())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions
  ): zio.aws.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-securityhub_2.13-5.20.32.1-sources.jar: zio/aws/securityhub/model/AwsElasticsearchDomainServiceSoftwareOptions.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.NonEmptyString
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class AwsElasticsearchDomainServiceSoftwareOptions(
    automatedUpdateDate: Optional[NonEmptyString] = Optional.Absent,
    cancellable: Optional[Boolean] = Optional.Absent,
    currentVersion: Optional[NonEmptyString] = Optional.Absent,
    description: Optional[NonEmptyString] = Optional.Absent,
    newVersion: Optional[NonEmptyString] = Optional.Absent,
    updateAvailable: Optional[Boolean] = Optional.Absent,
    updateStatus: Optional[NonEmptyString] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions = {
    import AwsElasticsearchDomainServiceSoftwareOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions
      .builder()
      .optionallyWith(
        automatedUpdateDate.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.automatedUpdateDate)
      .optionallyWith(cancellable.map(value => value: java.lang.Boolean))(
        _.cancellable
      )
      .optionallyWith(
        currentVersion.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.currentVersion)
      .optionallyWith(
        description.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(
        newVersion.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.newVersion)
      .optionallyWith(updateAvailable.map(value => value: java.lang.Boolean))(
        _.updateAvailable
      )
      .optionallyWith(
        updateStatus.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.updateStatus)
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions.ReadOnly =
    zio.aws.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions
      .wrap(buildAwsValue())
}
object AwsElasticsearchDomainServiceSoftwareOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions =
      zio.aws.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions(
        automatedUpdateDate.map(value => value),
        cancellable.map(value => value),
        currentVersion.map(value => value),
        description.map(value => value),
        newVersion.map(value => value),
        updateAvailable.map(value => value),
        updateStatus.map(value => value)
      )
    def automatedUpdateDate: Optional[NonEmptyString]
    def cancellable: Optional[Boolean]
    def currentVersion: Optional[NonEmptyString]
    def description: Optional[NonEmptyString]
    def newVersion: Optional[NonEmptyString]
    def updateAvailable: Optional[Boolean]
    def updateStatus: Optional[NonEmptyString]
    def getAutomatedUpdateDate: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("automatedUpdateDate", automatedUpdateDate)
    def getCancellable: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("cancellable", cancellable)
    def getCurrentVersion: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("currentVersion", currentVersion)
    def getDescription: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("description", description)
    def getNewVersion: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("newVersion", newVersion)
    def getUpdateAvailable: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("updateAvailable", updateAvailable)
    def getUpdateStatus: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("updateStatus", updateStatus)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions
  ) extends zio.aws.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions.ReadOnly {
    override val automatedUpdateDate: Optional[NonEmptyString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.automatedUpdateDate())
        .map(value =>
          zio.aws.securityhub.model.primitives.NonEmptyString(value)
        )
    override val cancellable: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.cancellable())
      .map(value => value: Boolean)
    override val currentVersion: Optional[NonEmptyString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.currentVersion())
        .map(value =>
          zio.aws.securityhub.model.primitives.NonEmptyString(value)
        )
    override val description: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val newVersion: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.newVersion())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val updateAvailable: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.updateAvailable())
      .map(value => value: Boolean)
    override val updateStatus: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.updateStatus())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions
  ): zio.aws.securityhub.model.AwsElasticsearchDomainServiceSoftwareOptions.ReadOnly =
    new Wrapper(impl)
}
